@@ -85,12 +85,8 @@ sub FromEtcTIMEZONE
         # A known timezone that we map to the Olson DB name
         if (exists $tztab_to_Olson{$tz}) {
             $tz = $tztab_to_Olson{$tz};
-        } elsif ($tz =~ /^GMT([+-])([1-9]?\d(?::(\d{2}))?)$/) {
-            my ($sign, $offset) = ($1, $2, $3);
-            $offset = '0' . $offset if length $offset < 2;
-            $offset .= '00' if length $offset == 2;
-            $tz = $sign . $offset;
         # A timezone without DST
+        # Note that GMT+5 gives -0500 as it is how HP-UX handles it
         } elsif ($tz =~ /^([A-Z]{3,})(-?)([1-9]?\d(?::(\d{2}))?)$/) {
             my ($name, $sign, $offset) = ($1, $2, $3);
             $offset = '0' . $offset if length $offset < 2;
@@ -120,7 +116,7 @@ DateTime::TimeZone::Local::hpux - Local timezone detection for HP-UX
 
 =head1 VERSION
 
-$Id: hpux.pm,v 1.2 2009/04/21 16:47:06 omengue Exp $
+$Id: hpux.pm,v 1.3 2009/04/21 17:20:37 omengue Exp $
 
 =head1 SYNOPSIS
 
